use lazy_static::lazy_static;
use rand::prelude::*;
use serde_json::json;

pub(crate) const APPLY_URL: &str = "https://test-oapi.gongyi.qq.com/api/tmj_third_service/";

pub(crate) const POST_CARD: &str = "PostCardInfo";
pub(crate) const TEST_DONATE_CARD_FULL: &str = "TestDonateCardFull";
pub(crate) const GY_HAPI_APPID: &str = "请找对接人"; //测试 APPID
pub(crate) const GY_HAPI_KEY: &str = "请找对接人";

fn generate_random_idcard() -> String {
    let mut rng = thread_rng();
    let chars = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '0'];
    let mut result: [char; 18] = ['\0'; 18];

    for (k, _) in result.clone().iter().enumerate() {
        result[k] = chars[rng.gen_range(0..9)].clone();
    }

    let r: String = result.iter().collect();
    format!("{}19940101{}", &r[0..6], &r[14..])
}

lazy_static! {
    //DDY_ZZ_ZZ_WZ 场景1:  捐款方式:多对一  卡片筹款维度:组织 卡片反馈维度:组织 资助类型:物资
    pub static ref DDY_ZZ_ZZ_WZ: serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000790,
    "project_name": "多对一组织组织物资",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
    "help_org_name": "大花岭小学",
    "help_org_address": {
    "province": "广东省",
    "city": "广州市",
    "area": "天河区",
    "detail": "江夏客厅"
    },
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00",
    "assistance_cycle_start_date":"2024-07-30",
    "assistance_cycle_end_date":"2024-07-31"
    });

    // DDY_ZZ_R_WZ 场景2:  捐款方式:多对一  卡片筹款维度:组织 卡片反馈维度:人 资助类型:物资
   pub static ref DDY_ZZ_R_WZ:serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000791,
    "project_name": "多对一组织人物资",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
    "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
            "stu_name":"张3",
            "stu_age":10,
            "stu_sex":"男",
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_images": [
                   "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/0ae8df37-3ae6-46c7-9190-b76b35e26531.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/77bd2664-15b9-4da2-91e4-26c9c3bcc4f8.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/8dd3bdc3-c01a-45fe-baa0-6665d3c65ff7.png"
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00"
});

    // DDY_ZZ_R_XJ 场景3: 捐款方式:多对一  卡片筹款维度:组织 卡片反馈维度:人 资助类型:现金
   pub static ref DDY_ZZ_R_XJ:serde_json::Value = {
        json!({
    "card_id":"",
    "project_id": 50000786,
    "project_name": "多对一组织人现金",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
     "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
           "stu_name":"张3",
           "id_card":generate_random_idcard(),
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_images": [
                   "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/0ae8df37-3ae6-46c7-9190-b76b35e26531.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/77bd2664-15b9-4da2-91e4-26c9c3bcc4f8.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/8dd3bdc3-c01a-45fe-baa0-6665d3c65ff7.png"
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00",
    "assistance_cycle_start_date":"2024-07-30",
    "assistance_cycle_end_date":"2024-07-31"
})
    };

    // DDY_R_R_WZ 场景4: 捐款方式:多对一  卡片筹款维度:人 卡片反馈维度:人 资助类型:物资
  pub  static ref DDY_R_R_WZ:serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000792,
    "project_name": "多对一人人物资",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
    "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
            "stu_name":"张3",
            "stu_age":10,
            "stu_sex":"男",
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_images": [
                   "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/0ae8df37-3ae6-46c7-9190-b76b35e26531.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/77bd2664-15b9-4da2-91e4-26c9c3bcc4f8.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/8dd3bdc3-c01a-45fe-baa0-6665d3c65ff7.png"
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00"
});
    // DDY_R_R_XJ 场景5: 捐款方式:多对一  卡片筹款维度:人 卡片反馈维度:人 资助类型:现金
  pub  static ref DDY_R_R_XJ:serde_json::Value = {
        json!(
    {
    "card_id":"",
    "project_id": 50000793,
    "project_name": "多对一人人现金",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
     "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
           "stu_name":"张3",
           "id_card": generate_random_idcard(),
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_images": [
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00",
    "assistance_cycle_start_date":"2024-07-30",
    "assistance_cycle_end_date":"2024-07-31"
}
        )
    };

    // YDY_ZZ_ZZ_WZ 场景6: 捐款方式:一对一  卡片筹款维度:组织 卡片反馈维度:组织 资助类型:物资
   pub static ref  YDY_ZZ_ZZ_WZ:serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000794,
    "project_name": "一对一组织组织物资",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
     "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00",
    "assistance_cycle_start_date":"2024-07-30",
    "assistance_cycle_end_date":"2024-07-31"
});
    // YDY_ZZ_R_WZ 场景7: 捐款方式:一对一  卡片筹款维度:组织 卡片反馈维度:人 资助类型:物资
   pub static ref YDY_ZZ_R_WZ:serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000795,
    "project_name": "一对一组织人物资",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
    "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
            "stu_name":"张3",
            "stu_age":10,
            "stu_sex":"男",
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_home_situation":"家庭困难",
           "stu_images": [
                   "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/0ae8df37-3ae6-46c7-9190-b76b35e26531.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/77bd2664-15b9-4da2-91e4-26c9c3bcc4f8.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/8dd3bdc3-c01a-45fe-baa0-6665d3c65ff7.png"
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00"
});
    // YDY_ZZ_R_XJ 场景8: 捐款方式:一对一  卡片筹款维度:组织 卡片反馈维度:人 资助类型:现金
  pub  static ref  YDY_ZZ_R_XJ:serde_json::Value = {
        json!(
        {
    "card_id":"",
    "project_id": 50000797,
    "project_name": "一对一组织人现金",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
     "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
           "stu_name":"张3",
           "id_card": generate_random_idcard(),
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_home_situation" :"家庭困难",
           "stu_images": [
                   "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/0ae8df37-3ae6-46c7-9190-b76b35e26531.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/77bd2664-15b9-4da2-91e4-26c9c3bcc4f8.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/8dd3bdc3-c01a-45fe-baa0-6665d3c65ff7.png"
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00",
    "assistance_cycle_start_date":"2024-07-30",
    "assistance_cycle_end_date":"2024-07-31"
})
        };

    // YDY_R_R_WZ 场景9: 捐款方式:一对一  卡片筹款维度:人 卡片反馈维度:人 资助类型:物资
   pub static ref YDY_R_R_WZ:serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000796,
    "project_name": "一对一人人物资",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
    "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
            "stu_name":"张3",
            "stu_age":10,
            "stu_sex":"男",
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_home_situation" :"家庭困难",
           "stu_images": [
                   "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/0ae8df37-3ae6-46c7-9190-b76b35e26531.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/77bd2664-15b9-4da2-91e4-26c9c3bcc4f8.png",
                    "https://proc-public-test-1258476242.cos.ap-shanghai.myqcloud.com/image/tmj/50000001/8dd3bdc3-c01a-45fe-baa0-6665d3c65ff7.png"
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00"
});
    // YDY_R_R_XJ 场景10: 捐款方式:一对一  卡片筹款维度:人 卡片反馈维度:人 资助类型:现金
   pub static ref  YDY_R_R_XJ:serde_json::Value = json!({
    "card_id":"",
    "project_id": 50000798,
    "project_name": "一对一人人现金",
    "help_org_number": "10000012",
    "card_target_description":"为大花岭小学小学生捐一块橡皮",
     "help_org_name": "大花岭小学",
    "help_org_address": {
        "province": "广东省",
        "city": "广州市",
        "area": "天河区",
        "detail": "江夏客厅"
    },
    "help_list": [
        {
            "stu_id": "stu_id_123456",
           "stu_name":"张3",
           "id_card": generate_random_idcard(),
           "school_grade_class": "一年级",
           "money": "0.5",
           "help_org_type":1,
           "school_name_simple": "大花岭大学",
           "stu_home_situation" :"家庭困难",
           "stu_images": [
           ],
           "fundras_target": "1.00",
           "identity": "小学生"
        }
    ],
    "help_thing_count": 1,
    "help_thing_target": "385",
    "help_thing_target": "1.00",
    "assistance_cycle_start_date":"2024-07-30",
    "assistance_cycle_end_date":"2024-07-31"
});
}
