mod r#const;

use hex;
use hmac::{Hmac, KeyInit, Mac};
use rand::distributions::Alphanumeric;
use rand::Rng;
use reqwest;
use reqwest::{Error, header, Response};
use serde_json::{json, Value};
use sha2::Sha256;
use std::collections::BTreeMap;
use std::sync::Arc;
use std::thread;
use std::time::{SystemTime, UNIX_EPOCH};
use tokio;
use tokio::runtime::Runtime;

//测试筹满, 注意修改 project_id和 card_id, 卡片必须是上线状态
async fn donate_full() -> Result<(), reqwest::Error> {
            let data = json!({"project_id":50000793, "card_id":"10105155"});
            let resp = reqwest::Client::new()
                .post(format!("{}{}",r#const::APPLY_URL , r#const::TEST_DONATE_CARD_FULL))
                .json(&data)
                .headers(generate_header())
                .send()
                .await;

            match resp.expect("REASON").text().await {
                Err(e) => {
                    eprintln!(
                        "err => {}, body => {}",
                        e,
                        serde_json::to_string_pretty(&data).unwrap()
                    )
                }
                Ok(t) => {
                    let r: BTreeMap<String, Value> = serde_json::from_str(&t).unwrap();
                    if r["code"] != 0 {
                        println!(
                            "t => {},body => {}",
                            serde_json::to_string_pretty(&t).unwrap(),
                            serde_json::to_string_pretty(&data).unwrap()
                        )
                    } else {
                        println!("RESP => {:?}", r)
                    }
                }
        };
    Ok(())
}

fn generate_header() -> header::HeaderMap {
    let mut m: BTreeMap<String, String> = BTreeMap::new();
    let mut rng = rand::thread_rng();
    let nonce: String = std::iter::repeat(())
        .map(|()| rng.sample(Alphanumeric))
        .map(char::from)
        .take(32)
        .into_iter()
        .collect();

    let time_stamp = SystemTime::now()
        .duration_since(UNIX_EPOCH)
        .unwrap()
        .as_secs();
    m.insert(
        "Gy-H-Api-Appid".to_string(),
        r#const::GY_HAPI_APPID.to_string(),
    );
    m.insert("Gy-H-Api-Timestamp".to_string(), time_stamp.to_string());
    m.insert("Gy-H-Api-Nonce-Str".to_string(), nonce.clone());

    let mut sign_str = String::from("");
    for (k, v) in m {
        sign_str += &*format!("{}={}&", &k, &v);
    }

    sign_str += &*format!("{}={}", "key", &r#const::GY_HAPI_KEY);

    println!("sign_str => {}", sign_str);

    let mut mac =
        Hmac::<Sha256>::new_from_slice(r#const::GY_HAPI_KEY.as_bytes()).expect("need hmac key");
    mac.update(sign_str.as_bytes());
    let result = mac.finalize();
    println!(
        "hmac => {}",
        hex::encode(result.into_bytes()).to_uppercase()
    );

    let mut headers = header::HeaderMap::new();
    headers.insert("Content-Type", "application/json".parse().unwrap());
    headers.insert("Gy-H-Api-Appid", r#const::GY_HAPI_APPID.parse().unwrap());
    headers.insert(
        "Gy-H-Api-Timestamp",
        time_stamp.to_string().parse().unwrap(),
    );

    let nonce = Arc::new(nonce.clone());
    let result = Arc::new(result);

    headers.insert("Gy-H-Api-Nonce-Str", (*nonce).parse().unwrap());
    headers.insert(
        "Gy-H-Api-Sign",
        hex::encode(result.into_bytes())
            .to_uppercase()
            .parse()
            .unwrap(),
    );

    headers.clone()
}

fn create_card() -> Result<(), reqwest::Error> {
    let data_array = [
        r#const::DDY_ZZ_ZZ_WZ.clone(),
        r#const::DDY_ZZ_R_WZ.clone(),
        r#const::DDY_ZZ_R_XJ.clone(),
        r#const::DDY_R_R_WZ.clone(),
        r#const::DDY_R_R_XJ.clone(),
        r#const::YDY_ZZ_ZZ_WZ.clone(),
        r#const::YDY_ZZ_R_XJ.clone(),
        r#const::YDY_R_R_WZ.clone(),
        r#const::YDY_R_R_XJ.clone(),
        r#const::YDY_ZZ_R_WZ.clone(),
    ];

    let mut handles = vec![];
    for i in data_array {
        let handler = thread::spawn(move || {
            let rt = Runtime::new().unwrap();
            rt.block_on(async {
                let resp: Result<Response, Error> = reqwest::Client::new()
                    .post(format!("{}{}",r#const::APPLY_URL , r#const::POST_CARD))
                    .json(&i)
                    .headers(generate_header())
                    .send()
                    .await;

                match resp.expect("REASON").text().await {
                    Err(e) => {
                        eprintln!(
                            "err => {}, body => {}",
                            serde_json::to_string_pretty(&e.to_string()).unwrap(),
                            serde_json::to_string_pretty(&i).unwrap()
                        )
                    }
                    Ok(t) => {
                        let r: BTreeMap<String, Value> = serde_json::from_str(&t).unwrap();
                        if r["code"] != 0 {
                            println!(
                                "t => {},body => {}",
                                serde_json::to_string_pretty(&t).unwrap(),
                                serde_json::to_string_pretty(&i).unwrap()
                            )
                        } else {
                            println!("RESP => {:?}", r)
                        }
                    }
                }
            });
        });

        handles.push(handler);
    }

    for h in handles {
        h.join().unwrap();
    }

    Ok(())
}

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
    create_card().expect("create card error");
    thread::sleep(std::time::Duration::from_secs(1));
    donate_full().await.expect("donate full error");
    Ok(())
}
